==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/users/loadUser.php <==
<?php
$userName = (isset($_REQUEST['userName']) && strlen($_REQUEST['userName']) >=1) ? $_REQUEST['userName'] : '';
$userMode = (isset($_REQUEST['userMode']) && strlen($_REQUEST['userMode']) >=1) ? $_REQUEST['userMode'] : '';

if ($userMode == 'addUser')	{
	$userText = 'Add User';
	$userClass = 'icon-user-plus';
	$usercn = $firstname = $lastname = $telephonenumber = $description = $dialplan = $homepage = $company = $currenthome = $initialphone = $logourl = $mail = $loginaccesscode = $voicemailaccesscode = $restrictgroups	= $hometelephonenumber = $mobiletelephonenumber	= $followme	= $followmeto = $forwardonbusy = $forwardonbusyto = $forwardonnoanswer = $forwardonnoanswerto = $callwaiting = $messageboxlicense = $operatorconsolelicense	= $navigatesoftphonelicense	= $navigatesfblicense = $navigateoutlooklicense = $ipcslicense = $siplicense = $usertype = $disabled = $totalcontrollicense = $noanswertime = $exdirectory = '';
	
	$sr=ldap_list($ds,"cn=Users","(objectclass=user)", array('telephonenumber'));
	$info = ldap_get_entries($ds, $sr); 
	for ($m=0; $m<$info['count']; $m++) {
	    $extn[$m] = ($info[$m]['telephonenumber'][0]);
	}
	
	$telephonenumber = (max($extn) === NULL) ? '2001' : max($extn) +1;
	
} else {
	$userText = ' - Edit User';
	$userClass = 'icon-pencil2';
	
	$sr=ldap_list($ds,"cn=Users","(cn=$userName)");
	$info = ldap_get_entries($ds, $sr); 
	
	$usercn 					= (isset($info[0]['cn'][0]) && strlen($info[0]['cn'][0]) >=1) 											? $info[0]['cn'][0] 					: '';
	$firstname 					= (isset($info[0]['givenname'][0]) && strlen($info[0]['givenname'][0]) >=1) 							? $info[0]['givenname'][0] 				: '';
	$lastname 					= (isset($info[0]['sn'][0]) && strlen($info[0]['sn'][0]) >=1) 											? $info[0]['sn'][0] 					: '';
	$telephonenumber 			= (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) 				? $info[0]['telephonenumber'][0] 		: '';
	$description 	 			= (isset($info[0]['description'][0]) && strlen($info[0]['description'][0]) >=1) 						? $info[0]['description'][0] 			: '';
	$dialplan 	 				= (isset($info[0]['dialplan'][0]) && strlen($info[0]['dialplan'][0]) >=1) 								? $info[0]['dialplan'][0] 				: '';
	$homepage 					= (isset($info[0]['homepage'][0]) && strlen($info[0]['homepage'][0]) >=1) 								? $info[0]['homepage'][0] 				: '';
	$company 					= (isset($info[0]['company'][0]) && strlen($info[0]['company'][0]) >=1) 								? $info[0]['company'][0] 				: '';
	$currenthome 				= (isset($info[0]['currenthome'][0]) && strlen($info[0]['currenthome'][0]) >=1) 						? $info[0]['currenthome'][0] 			: '';
	$initialphone 				= (isset($info[0]['initialphone'][0]) && strlen($info[0]['initialphone'][0]) >=1) 						? $info[0]['initialphone'][0] 			: '';
	$logourl 					= (isset($info[0]['logourl'][0]) && strlen($info[0]['logourl'][0]) >=1) 								? $info[0]['logourl'][0] 				: '';
	$mail 						= (isset($info[0]['mail'][0]) && strlen($info[0]['mail'][0]) >=1) 										? $info[0]['mail'][0] 					: '';
	$loginaccesscode 			= (isset($info[0]['loginaccesscode'][0]) && strlen($info[0]['loginaccesscode'][0]) >=1) 				? $info[0]['loginaccesscode'][0] 		: '';
	$voicemailaccesscode		= (isset($info[0]['voicemailaccesscode'][0]) && strlen($info[0]['voicemailaccesscode'][0]) >=1)			? $info[0]['voicemailaccesscode'][0] 	: '';
	$restrictgroups				= (isset($info[0]['restrictgroups'][0]) && strlen($info[0]['restrictgroups'][0]) >=1) 					? $info[0]['restrictgroups'][0] 		: '';
	$hometelephonenumber		= (isset($info[0]['hometelephonenumber'][0]) && strlen($info[0]['hometelephonenumber'][0]) >=1) 		? $info[0]['hometelephonenumber'][0] 	: '';
	$mobiletelephonenumber		= (isset($info[0]['mobiletelephonenumber'][0]) && strlen($info[0]['mobiletelephonenumber'][0]) >=1) 	? $info[0]['mobiletelephonenumber'][0] 	: '';
	$followme					= (isset($info[0]['followme'][0]) && strlen($info[0]['followme'][0]) >=1) 								? $info[0]['followme'][0] 				: '0';
	$followmeto					= (isset($info[0]['followmeto'][0]) && strlen($info[0]['followmeto'][0]) >=1) 							? $info[0]['followmeto'][0] 			: '';
	$noanswertime				= (isset($info[0]['noanswertime'][0]) && strlen($info[0]['noanswertime'][0]) >=1) 						? $info[0]['noanswertime'][0] 			: '0';
	$exdirectory				= (isset($info[0]['exdirectory'][0]) && strlen($info[0]['exdirectory'][0]) >=1) 						? $info[0]['exdirectory'][0] 			: '0';
	
	$forwardonbusy				= (isset($info[0]['forwardonbusy'][0]) && strlen($info[0]['forwardonbusy'][0]) >=1) 					? $info[0]['forwardonbusy'][0] 			: '0';
	$forwardonbusyto			= (isset($info[0]['forwardonbusyto'][0]) && strlen($info[0]['forwardonbusyto'][0]) >=1) 				? $info[0]['forwardonbusyto'][0] 		: '';
	$forwardonnoanswer			= (isset($info[0]['forwardonnoanswer'][0]) && strlen($info[0]['forwardonnoanswer'][0]) >=1) 			? $info[0]['forwardonnoanswer'][0] 		: '0';
	$forwardonnoanswerto		= (isset($info[0]['forwardonnoanswerto'][0]) && strlen($info[0]['forwardonnoanswerto'][0]) >=1) 		? $info[0]['forwardonnoanswerto'][0] 	: '';
	$callwaiting				= (isset($info[0]['callwaiting'][0]) && strlen($info[0]['callwaiting'][0]) >=1) 						? $info[0]['callwaiting'][0] 			: '';
	
	$messageboxlicense			= (isset($info[0]['messageboxlicense'][0]) && strlen($info[0]['messageboxlicense'][0]) >=1) 			? $info[0]['messageboxlicense'][0] 		: '';
	$operatorconsolelicense		= (isset($info[0]['operatorconsolelicense'][0]) && strlen($info[0]['operatorconsolelicense'][0]) >=1) 	? $info[0]['operatorconsolelicense'][0]	: '';
	$navigatesoftphonelicense	= (isset($info[0]['navigatesoftphonelicense'][0]) && strlen($info[0]['navigatesoftphonelicense'][0]) >=1) ? $info[0]['navigatesoftphonelicense'][0] : '';
	$navigatesfblicense			= (isset($info[0]['navigatesfblicense'][0]) && strlen($info[0]['navigatesfblicense'][0]) >=1) 			? $info[0]['navigatesfblicense'][0] 	: '';
	$navigateoutlooklicense		= (isset($info[0]['navigateoutlooklicense'][0]) && strlen($info[0]['navigateoutlooklicense'][0]) >=1) 	? $info[0]['navigateoutlooklicense'][0] : '';
	$ipcslicense				= (isset($info[0]['ipcslicense'][0]) && strlen($info[0]['ipcslicense'][0]) >=1) 						? $info[0]['ipcslicense'][0] 			: '';
	$siplicense					= (isset($info[0]['siplicense'][0]) && strlen($info[0]['siplicense'][0]) >=1) 							? $info[0]['siplicense'][0] 			: '';
	$usertype					= (isset($info[0]['usertype'][0]) && strlen($info[0]['usertype'][0]) >=1) 								? $info[0]['usertype'][0] 				: '';
	$disabled					= (isset($info[0]['disabled'][0]) && strlen($info[0]['disabled'][0]) >=1) 								? $info[0]['disabled'][0] 				: '';
	$totalcontrollicense		= (isset($info[0]['totalcontrollicense'][0]) && strlen($info[0]['totalcontrollicense'][0]) >=1) 		? $info[0]['totalcontrollicense'][0] 	: '';
}
?>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/users/loadUser.php <==
<?php
$userName = (isset($_REQUEST['userName']) && strlen($_REQUEST['userName']) >=1) ? $_REQUEST['userName'] : '';
$userGuid = (isset($_REQUEST['userGuid']) && strlen($_REQUEST['userGuid']) >=1) ? $_REQUEST['userGuid'] : '';
$userMode = (isset($_REQUEST['userMode']) && strlen($_REQUEST['userMode']) >=1) ? $_REQUEST['userMode'] : '';

if ($userMode == 'addUser')	{
	$userText = 'Add User';
	$userClass = 'icon-user-plus';
	$usercn = $firstname = $lastname = $telephonenumber = $description = $dialplan = $homepage = $company = $currenthome = $initialphone = $logourl = $mail = $loginaccesscode = $voicemailaccesscode = $restrictgroups	= $hometelephonenumber = $mobiletelephonenumber	= $followme	= $followmeto = $forwardonbusy = $forwardonbusyto = $forwardonnoanswer = $forwardonnoanswerto = $callwaiting = $messageboxlicense = $operatorconsolelicense	= $navigatesoftphonelicense	= $navigatesfblicense = $navigateoutlooklicense = $ipcslicense = $siplicense = $usertype = $disabled = $totalcontrollicense = $noanswertime = $exdirectory = $callselect = $donotdisturb = $voicemailenabled = $dectLine = '';
	
	$sr=ldap_list($ds,"cn=Users","(objectclass=user)", array('telephonenumber'));
	$info = ldap_get_entries($ds, $sr); 
	for ($m=0; $m<$info['count']; $m++) {
	    $extn[$m] = ($info[$m]['telephonenumber'][0]);
	}
	
	$telephonenumber = (max($extn) === NULL) ? '2001' : max($extn) +1;
	
} else {
	$userText = ' - Edit User';
	$userClass = 'icon-pencil2';
	
	$sr=ldap_list($ds,"cn=Users","(guid=$userGuid)");
	$info = ldap_get_entries($ds, $sr); 
	
	$usercn 					= (isset($info[0]['cn'][0]) && strlen($info[0]['cn'][0]) >=1) 											? $info[0]['cn'][0] 					: '';
	$firstname 					= (isset($info[0]['givenname'][0]) && strlen($info[0]['givenname'][0]) >=1) 							? $info[0]['givenname'][0] 				: '';
	$lastname 					= (isset($info[0]['sn'][0]) && strlen($info[0]['sn'][0]) >=1) 											? $info[0]['sn'][0] 					: '';
	$telephonenumber 			= (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) 				? $info[0]['telephonenumber'][0] 		: '';
	$description 	 			= (isset($info[0]['description'][0]) && strlen($info[0]['description'][0]) >=1) 						? $info[0]['description'][0] 			: '';
	$dialplan 	 				= (isset($info[0]['dialplan'][0]) && strlen($info[0]['dialplan'][0]) >=1) 								? $info[0]['dialplan'][0] 				: '';
	$homepage 					= (isset($info[0]['homepage'][0]) && strlen($info[0]['homepage'][0]) >=1) 								? $info[0]['homepage'][0] 				: '';
	$company 					= (isset($info[0]['company'][0]) && strlen($info[0]['company'][0]) >=1) 								? $info[0]['company'][0] 				: '';
	$currenthome 				= (isset($info[0]['currenthome'][0]) && strlen($info[0]['currenthome'][0]) >=1) 						? $info[0]['currenthome'][0] 			: '';
	$initialphone 				= (isset($info[0]['initialphone'][0]) && strlen($info[0]['initialphone'][0]) >=1) 						? $info[0]['initialphone'][0] 			: '';
	$logourl 					= (isset($info[0]['logourl'][0]) && strlen($info[0]['logourl'][0]) >=1) 								? $info[0]['logourl'][0] 				: '';
	$mail 						= (isset($info[0]['mail'][0]) && strlen($info[0]['mail'][0]) >=1) 										? $info[0]['mail'][0] 					: '';
	$loginaccesscode 			= (isset($info[0]['loginaccesscode'][0]) && strlen($info[0]['loginaccesscode'][0]) >=1) 				? $info[0]['loginaccesscode'][0] 		: '';
	$voicemailaccesscode		= (isset($info[0]['voicemailaccesscode'][0]) && strlen($info[0]['voicemailaccesscode'][0]) >=1)			? $info[0]['voicemailaccesscode'][0] 	: '';
	$restrictgroups				= (isset($info[0]['restrictgroups'][0]) && strlen($info[0]['restrictgroups'][0]) >=1) 					? $info[0]['restrictgroups'][0] 		: '';
	$hometelephonenumber		= (isset($info[0]['hometelephonenumber'][0]) && strlen($info[0]['hometelephonenumber'][0]) >=1) 		? $info[0]['hometelephonenumber'][0] 	: '';
	$mobiletelephonenumber		= (isset($info[0]['mobiletelephonenumber'][0]) && strlen($info[0]['mobiletelephonenumber'][0]) >=1) 	? $info[0]['mobiletelephonenumber'][0] 	: '';
	$followme					= (isset($info[0]['followme'][0]) && strlen($info[0]['followme'][0]) >=1) 								? $info[0]['followme'][0] 				: '0';
	$followmeto					= (isset($info[0]['followmeto'][0]) && strlen($info[0]['followmeto'][0]) >=1) 							? $info[0]['followmeto'][0] 			: '';
	$noanswertime				= (isset($info[0]['noanswertime'][0]) && strlen($info[0]['noanswertime'][0]) >=1) 						? $info[0]['noanswertime'][0] 			: '0';
	$exdirectory				= (isset($info[0]['exdirectory'][0]) && strlen($info[0]['exdirectory'][0]) >=1) 						? $info[0]['exdirectory'][0] 			: '0';
	$callselect					= (isset($info[0]['allowmultiplephones'][0]) && strlen($info[0]['allowmultiplephones'][0]) >=1) 		? $info[0]['allowmultiplephones'][0] 	: '0';
	$donotdisturb				= (isset($info[0]['donotdisturb'][0]) && strlen($info[0]['donotdisturb'][0]) >=1) 						? $info[0]['donotdisturb'][0] 			: '0';
	$voicemailenabled			= (isset($info[0]['voicemailenabled'][0]) && strlen($info[0]['voicemailenabled'][0]) >=1) 				? $info[0]['voicemailenabled'][0] 		: '0';
	$dectline					= (isset($info[0]['dectline'][0]) && strlen($info[0]['dectline'][0]) >=1) 								? $info[0]['dectline'][0] 				: '';
	
	$forwardonbusy				= (isset($info[0]['forwardonbusy'][0]) && strlen($info[0]['forwardonbusy'][0]) >=1) 					? $info[0]['forwardonbusy'][0] 			: '0';
	$forwardonbusyto			= (isset($info[0]['forwardonbusyto'][0]) && strlen($info[0]['forwardonbusyto'][0]) >=1) 				? $info[0]['forwardonbusyto'][0] 		: '';
	$forwardonnoanswer			= (isset($info[0]['forwardonnoanswer'][0]) && strlen($info[0]['forwardonnoanswer'][0]) >=1) 			? $info[0]['forwardonnoanswer'][0] 		: '0';
	$forwardonnoanswerto		= (isset($info[0]['forwardonnoanswerto'][0]) && strlen($info[0]['forwardonnoanswerto'][0]) >=1) 		? $info[0]['forwardonnoanswerto'][0] 	: '';
	$callwaiting				= (isset($info[0]['callwaiting'][0]) && strlen($info[0]['callwaiting'][0]) >=1) 						? $info[0]['callwaiting'][0] 			: '';
	
	$messageboxlicense			= (isset($info[0]['messageboxlicense'][0]) && strlen($info[0]['messageboxlicense'][0]) >=1) 			? $info[0]['messageboxlicense'][0] 		: '';
	$operatorconsolelicense		= (isset($info[0]['operatorconsolelicense'][0]) && strlen($info[0]['operatorconsolelicense'][0]) >=1) 	? $info[0]['operatorconsolelicense'][0]	: '';
	$navigatesoftphonelicense	= (isset($info[0]['navigatesoftphonelicense'][0]) && strlen($info[0]['navigatesoftphonelicense'][0]) >=1) ? $info[0]['navigatesoftphonelicense'][0] : '';
	$navigatesfblicense			= (isset($info[0]['navigatesfblicense'][0]) && strlen($info[0]['navigatesfblicense'][0]) >=1) 			? $info[0]['navigatesfblicense'][0] 	: '';
	$navigateoutlooklicense		= (isset($info[0]['navigateoutlooklicense'][0]) && strlen($info[0]['navigateoutlooklicense'][0]) >=1) 	? $info[0]['navigateoutlooklicense'][0] : '';
	$ipcslicense				= (isset($info[0]['ipcslicense'][0]) && strlen($info[0]['ipcslicense'][0]) >=1) 						? $info[0]['ipcslicense'][0] 			: '';
	$siplicense					= (isset($info[0]['siplicense'][0]) && strlen($info[0]['siplicense'][0]) >=1) 							? $info[0]['siplicense'][0] 			: '';
	$usertype					= (isset($info[0]['usertype'][0]) && strlen($info[0]['usertype'][0]) >=1) 								? $info[0]['usertype'][0] 				: '';
	$disabled					= (isset($info[0]['disabled'][0]) && strlen($info[0]['disabled'][0]) >=1) 								? $info[0]['disabled'][0] 				: '';
	$totalcontrollicense		= (isset($info[0]['totalcontrollicense'][0]) && strlen($info[0]['totalcontrollicense'][0]) >=1) 		? $info[0]['totalcontrollicense'][0] 	: '';
}
?>
